@@ -13,7 +13,7 @@ use CGI::Cookie;
 require POSIX;
 use Lemonldap::NG::Portal::_i18n;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 our @ISA = qw(CGI Exporter);
 
@@ -131,33 +131,45 @@ sub header {
 # CGI.pm overload to add Lemonldap::NG cookie
 sub redirect {
     my $self = shift;
-    if ( $_[0]->{cookie} ) {
-        $self->SUPER::redirect( @_, -cookie => $_[0]->{cookie} );
+    if ( $self->{cookie} ) {
+        $self->SUPER::redirect( @_, -cookie => $self->{cookie} );
     }
     else {
         $self->SUPER::redirect(@_);
     }
 }
 
+# Externalise functions execution
+sub _subProcess {
+    my $self = shift;
+    my @subs = @_;
+    my $err  = undef;
+
+    foreach my $sub (@subs) {
+        if ( $self->{$sub} ) {
+            last if ( $err = &{ $self->{$sub} }($self) );
+        }
+        else {
+            last if ( $err = $self->$sub );
+        }
+    }
+
+    return $err;
+}
+
 ###############################################################
 # MAIN subroutine: call all steps until one returns something #
 #                  different than PE_OK                       #
 ###############################################################
+
 sub process {
     my ($self) = @_;
     $self->{error} = PE_OK;
-    foreach my $sub
+    $self->{error} = $self->_subProcess(
       qw(controlUrlOrigin controlExistingSession extractFormInfo formateParams
       formateFilter connectLDAP bind search setSessionInfo setMacros setGroups
-      authenticate store unbind buildCookie log autoRedirect) {
-        if ( $self->{$sub} )
-        {
-            last if ( $self->{error} = &{ $self->{$sub} }($self) );
-        }
-        else {
-            last if ( $self->{error} = $self->$sub );
-        }
-      }
+      authenticate store unbind buildCookie log autoRedirect)
+      );
       return ( ( $self->{error} > 0 ) ? 0 : 1 );
 }
 
